Documentation
¶
Index ¶
- Constants
- func ReadGzip(path string) ([]byte, error)
- type API
- type DSA
- func (d *DSA) GenerateKeyPair(seed [common.SeedSize]byte) (fips204.PublicKey, fips204.PrivateKey)
- func (d *DSA) IsPrivateKeyValid(srcSk, targetSk fips204.PrivateKey) bool
- func (d *DSA) IsPublicKeyValid(srcPk, targetPk fips204.PublicKey) bool
- func (d *DSA) MarshalPrivateKey(sk fips204.PrivateKey) []byte
- func (d *DSA) MarshalPublicKey(pk fips204.PublicKey) []byte
- func (d *DSA) Scheme() string
- func (d *DSA) Sign(secretBytes []byte, msgBytes []byte, rnd [32]byte) []byte
- func (d *DSA) UnmarshalPrivateKey(buf []byte) fips204.PrivateKey
- func (d *DSA) UnmarshalPublicKey(buf []byte) fips204.PublicKey
- func (d *DSA) Verify(publicBytes, signatureBytes []byte, msgBytes []byte) bool
- type HexBytes
- type Level
Constants ¶
const ( Level2 = iota Level3 Level5 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type API ¶
type API interface {
Scheme() string
GenerateKeyPair(seed [common.SeedSize]byte) (fips204.PublicKey, fips204.PrivateKey)
Sign(secretBytes []byte, msgBytes []byte, rnd [32]byte) []byte
Verify(publicBytes, signatureBytes []byte, msgBytes []byte) bool
MarshalPublicKey(pk fips204.PublicKey) []byte
MarshalPrivateKey(sk fips204.PrivateKey) []byte
UnmarshalPublicKey(buf []byte) fips204.PublicKey
UnmarshalPrivateKey(buf []byte) fips204.PrivateKey
IsPublicKeyValid(srcPk, targetPk fips204.PublicKey) bool
IsPrivateKeyValid(srcSk, targetSk fips204.PrivateKey) bool
}
func WithFIPS204 ¶
type DSA ¶
type DSA struct {
// contains filtered or unexported fields
}
func (*DSA) GenerateKeyPair ¶
func (*DSA) IsPrivateKeyValid ¶
func (d *DSA) IsPrivateKeyValid(srcSk, targetSk fips204.PrivateKey) bool
func (*DSA) IsPublicKeyValid ¶
func (*DSA) MarshalPrivateKey ¶
func (d *DSA) MarshalPrivateKey(sk fips204.PrivateKey) []byte
func (*DSA) UnmarshalPrivateKey ¶
func (d *DSA) UnmarshalPrivateKey(buf []byte) fips204.PrivateKey
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
sign
Package sign implements Module Lattice Digital Signature Algorithm (ML-DSA) (Dilithium) scheme.
|
Package sign implements Module Lattice Digital Signature Algorithm (ML-DSA) (Dilithium) scheme. |
|
protocol
|
|
|
fips204
Package fips204 implements the ML-DSA (Module Lattice Digital Signature Algorithm) protocol as standardized in NIST FIPS 204.
|
Package fips204 implements the ML-DSA (Module Lattice Digital Signature Algorithm) protocol as standardized in NIST FIPS 204. |
Click to show internal directories.
Click to hide internal directories.